/***************************************************************************
                          frontend.cpp  -  description
                             -------------------
    begin                : Sat Oct 30 1999
    copyright            : (C) 1999 by Peter van Eerten
    email                : emphroon@yahoo.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qapplication.h>				//Qt libs
#include <qmessagebox.h>
#include <qpixmap.h>
#include <qfont.h>

#include <string.h>
#include <stdlib.h> 					//needed for linux system calls
#include <iostream.h>

#include "frontend.h"
#include "dialog.h"

//****************************************************************************************

radiofrontend::radiofrontend (QWidget *parent, const char *name)
	      :QWidget (parent, name)
{
mutetoggle = true;
command = new char[60];
freq1 = new char [5]; freq2 = new char [5];		//read frequency variable
freq3 = new char [5]; freq4 = new char [5];
freq5 = new char [5]; freq6 = new char [5];		//read frequency variable
freq7 = new char [5]; freq8 = new char [5];
last = new char [2];
homedir = new char [60];				//homedirectory not longer than 60 chars
homedir = getenv ("HOME");

//***************** icon handling routines

bool found = false; 					//this is the icon in the titlebar
char *where = new char [80];
QPixmap icon;                           		
if (homedir != NULL)
{
strcpy (where, homedir);					//is there an icon in $HOME?
strcat (where, "/mini-qradio.xpm");
bool set1 = icon.load(where);
if (set1) {setIcon (icon); found = true;}		
else							//no, look in global kde dir Mandrake 7 
{
strcpy (where, "/usr/share/icons/mini/mini-qradio.xpm");
bool set2 = icon.load(where);
if (set2) {setIcon (icon); found = true;}		
}
}
if (!found)									//last possibility: environment variable
{											//$QTRADIO_ICON_PATH
where = getenv ("QRADIO_ICON_PATH");
if (where != NULL)               			//Bug fixed oct 25 1999
{
strcat (where, "/mini-qradio.xpm");
bool set3 = icon.load(where);
if (set3) setIcon (icon);
}
}

//**************** end of icon handling routines

setFont (QFont("Helvetica", 16));					//Adjusted size and amount of preset buttons oct 25 1999
setMinimumSize (310, 170);							//fixate size of application
setMaximumSize (310, 170);
setCaption ("Qradio 0.5.3");

radiobuttons = new QButtonGroup (this, "Buttongroup");
radiobuttons -> setExclusive (TRUE);
radiobuttons -> setGeometry (15, 15, 15, 15);  				//hide buttongroup under pushbutton

radio1 = new QPushButton ("Radio 1", this);
radio1 -> setGeometry (10, 10, 60, 30);
radio1 -> setToggleButton (TRUE);
connect (radio1, SIGNAL (clicked()), SLOT(setfreq1()));
radiobuttons -> insert (radio1);

radio2 = new QPushButton ("Radio 2", this);
radio2 -> setGeometry (10, 50, 60, 30);
radio2 -> setToggleButton (TRUE);
connect (radio2, SIGNAL (clicked()), SLOT(setfreq2()));
radiobuttons -> insert (radio2);

radio3 = new QPushButton ("Radio 3", this);
radio3 -> setGeometry (10, 90, 60, 30);
radio3 -> setToggleButton (TRUE);
connect (radio3, SIGNAL (clicked()), SLOT(setfreq3()));
radiobuttons -> insert (radio3);

radio4 = new QPushButton ("Radio 4", this);
radio4 -> setGeometry (10, 130, 60, 30);
radio4 -> setToggleButton (TRUE);
connect (radio4, SIGNAL (clicked()), SLOT(setfreq4()));
radiobuttons -> insert (radio4);

radio5 = new QPushButton ("Radio 5", this);
radio5 -> setGeometry (80, 10, 60, 30);
radio5 -> setToggleButton (TRUE);
connect (radio5, SIGNAL (clicked()), SLOT(setfreq5()));
radiobuttons -> insert (radio5);

radio6 = new QPushButton ("Radio 6", this);
radio6 -> setGeometry (80, 50, 60, 30);
radio6 -> setToggleButton (TRUE);
connect (radio6, SIGNAL (clicked()), SLOT(setfreq6()));
radiobuttons -> insert (radio6);

radio7 = new QPushButton ("Radio 7", this);
radio7 -> setGeometry (80, 90, 60, 30);
radio7 -> setToggleButton (TRUE);
connect (radio7, SIGNAL (clicked()), SLOT(setfreq7()));
radiobuttons -> insert (radio7);

radio8 = new QPushButton ("Radio 8", this);
radio8 -> setGeometry (80, 130, 60, 30);
radio8 -> setToggleButton (TRUE);
connect (radio8, SIGNAL (clicked()), SLOT(setfreq8()));
radiobuttons -> insert (radio8);

volume = new QPushButton ("Mute on", this);
volume -> setGeometry (150, 90, 70, 30);
volume -> setPalette (QPalette (QColor (80, 80, 80)));
connect (volume, SIGNAL (clicked()), SLOT(volset()));

about = new QPushButton ("About", this);
about -> setGeometry (150, 130, 70, 30);
about -> setPalette (QPalette (QColor (80, 80, 80)));
connect (about, SIGNAL (clicked()), SLOT(aboutmsg()));

options = new QPushButton ("Options...", this);
options -> setGeometry (230, 90, 70, 30);
options -> setPalette (QPalette (QColor (80, 80, 80)));
connect (options, SIGNAL (clicked()), SLOT(opendialog()));

quit = new QPushButton ("Quit", this);
quit -> setGeometry (230, 130, 70, 30);
quit -> setPalette (QPalette (QColor (80, 80, 80)));
connect (quit, SIGNAL (clicked()), SLOT(quitfrontend()));

band = new QLCDNumber (4, this, "lcd");
band -> setGeometry (150, 10, 150, 70);
band -> setSmallDecimalPoint (true);
band -> setPalette (QPalette (QColor (100, 100, 100)));

if (homedir != NULL)							//check file in home directory
{
strcpy (temp, homedir);							//exists? open it
strcat (temp, "/.qradiorc");
defaults = fopen (temp, "r");
}
else defaults = fopen (".qradiorc", "r");		//otherwise, just open file in current dir

if (defaults != NULL)							//is there no file at all?
{
fscanf (defaults, "%s", freq1);					//read frequency's into temporary local vars
fscanf (defaults, "%s", freq2);
fscanf (defaults, "%s", freq3);
fscanf (defaults, "%s", freq4);
fscanf (defaults, "%s", freq5);					//read frequency's into temporary local vars
fscanf (defaults, "%s", freq6);
fscanf (defaults, "%s", freq7);
fscanf (defaults, "%s", freq8);
fscanf (defaults, "%s", last);
fclose (defaults);
}
strcpy (temp, "fm ");					// initialize radio for first-time use
if (*last == 49) {strcat (temp, freq1); band -> display (freq1);radio1 -> toggle();}
if (*last == 50) {strcat (temp, freq2); band -> display (freq2);radio2 -> toggle();}
if (*last == 51) {strcat (temp, freq3); band -> display (freq3);radio3 -> toggle();}
if (*last == 52) {strcat (temp, freq4); band -> display (freq4);radio4 -> toggle();}
if (*last == 53) {strcat (temp, freq5); band -> display (freq5);radio5 -> toggle();}
if (*last == 54) {strcat (temp, freq6); band -> display (freq6);radio6 -> toggle();}
if (*last == 55) {strcat (temp, freq7); band -> display (freq7);radio7 -> toggle();}
if (*last == 56) {strcat (temp, freq8); band -> display (freq8);radio8 -> toggle();}
strcat (temp, " 65535");				//put to maximum volume
command = temp;
system (command);
}

void radiofrontend::volset ()
{
if (mutetoggle)
{
 	strcpy (temp,"fm off");
	command = temp;
	system (command);
	mutetoggle = false;
	volume -> setText ("Mute off");
}
else
{
	strcpy (temp, "fm on");
	command = temp;
	system (command);

	strcpy (temp, "fm ");
	if (*last == 49) {strcat (temp, freq1); band -> display (freq1);}
	if (*last == 50) {strcat (temp, freq2); band -> display (freq2);}
	if (*last == 51) {strcat (temp, freq3); band -> display (freq3);}
	if (*last == 52) {strcat (temp, freq4); band -> display (freq4);}
        if (*last == 53) {strcat (temp, freq5); band -> display (freq5);}
	if (*last == 54) {strcat (temp, freq6); band -> display (freq6);}
	if (*last == 55) {strcat (temp, freq7); band -> display (freq7);}
	if (*last == 56) {strcat (temp, freq8); band -> display (freq8);}
	strcat (temp, " 65535");					//put to maximum volume
	command = temp;
	system (command);

	mutetoggle = true;
	volume -> setText ("Mute on");
}
}

void radiofrontend::aboutmsg()
{
QMessageBox::information (this, "About Qradio",
			  "This program is published under the GNU license.\n\n"
			  "        Written by Peter van Eerten.\n\n"
			  "     Thanks to Jason Lewis for writing\n"
			  "       the driver for 2.0.x kernels.\n"
			  "     Thanks to Russel Kroll for porting\n"
			  "       the driver to kernels > 2.1.\n\n"
			  "   You can find the latest information\n"
			  "       about Qradio on internet at:\n\n"
			  "http://www.geocities.com/TimesSquare/Corner/6262\n");
return;
}

void radiofrontend::quitfrontend()
{
if (homedir != NULL)							//first read frequency settings
{
strcpy (temp, homedir);							//exists? open it
strcat (temp, "/.qradiorc");
defaults = fopen (temp, "r");
}
else defaults = fopen (".qradiorc", "r");		//otherwise, just open file in current dir

if (defaults != NULL)
{
fscanf (defaults, "%s", freq1);
fscanf (defaults, "%s", freq2);
fscanf (defaults, "%s", freq3);
fscanf (defaults, "%s", freq4);
fscanf (defaults, "%s", freq5);
fscanf (defaults, "%s", freq6);
fscanf (defaults, "%s", freq7);
fscanf (defaults, "%s", freq8);
fclose (defaults);
}

if (homedir != NULL)					//now save settings and current frequency again
{
strcpy (temp, homedir);					//goto homedirectory if $HOME is existing
strcat (temp, "/.qradiorc");
defaults = fopen (temp, "w");
}
else defaults = fopen (".qradiorc", "w");		//otherwise, use current directory

fprintf (defaults, " "); fprintf (defaults, freq1);	//save frequency's to .qtradiorc
fprintf (defaults, " "); fprintf (defaults, freq2);
fprintf (defaults, " "); fprintf (defaults, freq3);
fprintf (defaults, " "); fprintf (defaults, freq4);
fprintf (defaults, " "); fprintf (defaults, freq5);	
fprintf (defaults, " "); fprintf (defaults, freq6);
fprintf (defaults, " "); fprintf (defaults, freq7);
fprintf (defaults, " "); fprintf (defaults, freq8);
fprintf (defaults, " "); fprintf (defaults, last);	//save last chosen frequency as well
fclose (defaults);

command = "fm off";
system (command);									//mute radio

QApplication::exit();								//exit application
}

void radiofrontend::setfreq1()						//first, read .qtradiorc, then set frequency
{
if (homedir != NULL)								//check file in home directory
{
strcpy (temp, homedir);								//exists? open it
strcat (temp, "/.qradiorc");
defaults = fopen (temp, "r");
}
else defaults = fopen (".qradiorc", "r");			//otherwise, just open file in current dir

if (defaults != NULL)
{
fscanf (defaults, "%s", freq1);
fclose (defaults);
}
strcpy (temp, "fm ");
strcat (temp, freq1);
strcat (temp, " 65535");
command = temp;									//convert to char pointer
system (command);
band -> display (freq1);
last = "1";
mutetoggle = true;
volume -> setText ("Mute on");
}

void radiofrontend::setfreq2()
{
if (homedir != NULL)							//check file in home directory
{
strcpy (temp, homedir);							//exists? open it
strcat (temp, "/.qradiorc");
defaults = fopen (temp, "r");
}
else defaults = fopen (".qradiorc", "r");		//otherwise, just open file in current dir

if (defaults != NULL)
{
fscanf (defaults, "%s", freq1);
fscanf (defaults, "%s", freq2);
fclose (defaults);
}
strcpy (temp, "fm ");
strcat (temp, freq2);
strcat (temp, " 65535");
command = temp;
system (command);
band -> display (freq2);
last = "2";
mutetoggle = true;
volume -> setText ("Mute on");
}

void radiofrontend::setfreq3()
{
if (homedir != NULL)							//check file in home directory
{
strcpy (temp, homedir);							//exists? open it
strcat (temp, "/.qradiorc");
defaults = fopen (temp, "r");
}
else defaults = fopen (".qradiorc", "r");		//otherwise, just open file in current dir

if (defaults != NULL)
{
fscanf (defaults, "%s", freq1);
fscanf (defaults, "%s", freq2);
fscanf (defaults, "%s", freq3);
fclose (defaults);
}
strcpy (temp, "fm ");
strcat (temp, freq3);
strcat (temp, " 65535");
command = temp;
system (command);
band -> display (freq3);
last = "3";
mutetoggle = true;
volume -> setText ("Mute on");
}

void radiofrontend::setfreq4()
{
if (homedir != NULL)							//check file in home directory
{
strcpy (temp, homedir);							//exists? open it
strcat (temp, "/.qradiorc");
defaults = fopen (temp, "r");
}
else defaults = fopen (".qradiorc", "r");		//otherwise, just open file in current dir

if (defaults != NULL)
{
fscanf (defaults, "%s", freq1);
fscanf (defaults, "%s", freq2);
fscanf (defaults, "%s", freq3);
fscanf (defaults, "%s", freq4);
fclose (defaults);
}
strcpy (temp, "fm ");
strcat (temp, freq4);
strcat (temp, " 65535");
command = temp;
system (command);
band -> display (freq4);
last = "4";
mutetoggle = true;
volume -> setText ("Mute on");
}

void radiofrontend::setfreq5()
{
if (homedir != NULL)							//check file in home directory
{
strcpy (temp, homedir);							//exists? open it
strcat (temp, "/.qradiorc");
defaults = fopen (temp, "r");
}
else defaults = fopen (".qradiorc", "r");		//otherwise, just open file in current dir

if (defaults != NULL)
{
fscanf (defaults, "%s", freq1);
fscanf (defaults, "%s", freq2);
fscanf (defaults, "%s", freq3);
fscanf (defaults, "%s", freq4);
fscanf (defaults, "%s", freq5);
fclose (defaults);
}
strcpy (temp, "fm ");
strcat (temp, freq5);
strcat (temp, " 65535");
command = temp;
system (command);
band -> display (freq5);
last = "5";
mutetoggle = true;
volume -> setText ("Mute on");
}

void radiofrontend::setfreq6()
{
if (homedir != NULL)							//check file in home directory
{
strcpy (temp, homedir);							//exists? open it
strcat (temp, "/.qradiorc");
defaults = fopen (temp, "r");
}
else defaults = fopen (".qradiorc", "r");		//otherwise, just open file in current dir

if (defaults != NULL)
{
fscanf (defaults, "%s", freq1);
fscanf (defaults, "%s", freq2);
fscanf (defaults, "%s", freq3);
fscanf (defaults, "%s", freq4);
fscanf (defaults, "%s", freq5);
fscanf (defaults, "%s", freq6);
fclose (defaults);
}
strcpy (temp, "fm ");
strcat (temp, freq6);
strcat (temp, " 65535");
command = temp;
system (command);
band -> display (freq6);
last = "6";
mutetoggle = true;
volume -> setText ("Mute on");
}

void radiofrontend::setfreq7()
{
if (homedir != NULL)							//check file in home directory
{
strcpy (temp, homedir);							//exists? open it
strcat (temp, "/.qradiorc");
defaults = fopen (temp, "r");
}
else defaults = fopen (".qradiorc", "r");		//otherwise, just open file in current dir

if (defaults != NULL)
{
fscanf (defaults, "%s", freq1);
fscanf (defaults, "%s", freq2);
fscanf (defaults, "%s", freq3);
fscanf (defaults, "%s", freq4);
fscanf (defaults, "%s", freq5);
fscanf (defaults, "%s", freq6);
fscanf (defaults, "%s", freq7);
fclose (defaults);
}
strcpy (temp, "fm ");
strcat (temp, freq7);
strcat (temp, " 65535");
command = temp;
system (command);
band -> display (freq7);
last = "7";
mutetoggle = true;
volume -> setText ("Mute on");
}

void radiofrontend::setfreq8()
{
if (homedir != NULL)								//check file in home directory
{
strcpy (temp, homedir);								//exists? open it
strcat (temp, "/.qradiorc");
defaults = fopen (temp, "r");
}
else defaults = fopen (".qradiorc", "r");			//otherwise, just open file in current dir

if (defaults != NULL)
{
fscanf (defaults, "%s", freq1);
fscanf (defaults, "%s", freq2);
fscanf (defaults, "%s", freq3);
fscanf (defaults, "%s", freq4);
fscanf (defaults, "%s", freq5);
fscanf (defaults, "%s", freq6);
fscanf (defaults, "%s", freq7);
fscanf (defaults, "%s", freq8);
fclose (defaults);
}
strcpy (temp, "fm ");
strcat (temp, freq8);
strcat (temp, " 65535");
command = temp;
system (command);
band -> display (freq8);
last = "8";
mutetoggle = true;
volume -> setText ("Mute on");
}

void radiofrontend::select()
{
}

void radiofrontend::opendialog()
{
interview Questions;
Questions.setMinimumSize (250, 200);					//fixate size
Questions.setMaximumSize (250, 200);
if (radio1->isOn()) Questions.select (1);
if (radio2->isOn()) Questions.select (2);
if (radio3->isOn()) Questions.select (3);
if (radio4->isOn()) Questions.select (4);
if (radio5->isOn()) Questions.select (5);
if (radio6->isOn()) Questions.select (6);
if (radio7->isOn()) Questions.select (7);
if (radio8->isOn()) Questions.select (8);
Questions.frontend_ptr = this;
Questions.show();
}

//****************************************************************************************************

